@@ -10,10 +10,10 @@ select.model.list <- function(data, observed = TRUE, cent.tend = median, rarefac
         ## If disparity is a single value
         if(unique(unlist(lapply(data$disparity, lapply, lapply, length))) != 1) {
             ## Calculate the variance from the disparity data
-            variance <- unlist(lapply(extract.dispRity(data, observed = FALSE), lapply, var))
+            variance <- unlist(lapply(extract.dispRity(data, observed = FALSE), lapply, var, na.rm = TRUE))
         } else {
             ## Extract directly the variance from the data
-            variance <- sapply(data[[3]], function(x) var(data[[1]][x[[1]]]))
+            variance <- sapply(data[[3]], function(x) var(data[[1]][x[[1]]], na.rm = TRUE))
         }
 
     } else {
@@ -27,7 +27,7 @@ select.model.list <- function(data, observed = TRUE, cent.tend = median, rarefac
         ## Calculating the central tendency
         central_tendency <- unlist(lapply(disparity_tmp, lapply, cent.tend))
         ## Calculating the variance
-        variance <- unlist(lapply(disparity_tmp, lapply, var))
+        variance <- unlist(lapply(disparity_tmp, lapply, var, na.rm = TRUE))
     }
 
     ## Getting the length of the samples
@@ -45,13 +45,13 @@ select.model.list <- function(data, observed = TRUE, cent.tend = median, rarefac
         subsets <- seq(1:length(data$subsets))
     }
     
-    subsets <- max(subsets) - subsets
+    subsets_out <- max(subsets) - subsets
 
     ## Returns the data
     return(list("central_tendency" = central_tendency,
                 "variance" = variance,
                 "sample_size" = sample_length,
-                "subsets" = rev(subsets)))
+                "subsets" = rev(subsets_out)))
 }
 
 
@@ -61,68 +61,70 @@ get.parameters <- function(model.output.pars, models, time.split, fixed.optima=N
      
     n.models <- length(models)
     first.model <- models[1]
-     
-    if(first.model == "BM") {
-        parameters.out <- model.output.pars[c(1,2)]
+    
+    switch(first.model,
+        BM = {
+            parameters.out <- model.output.pars[c(1,2)]
+        },
+        OU = {
+            parameters.out <- model.output.pars[c(1:4)]
+            if(fixed.optima) {
+                parameters.out <- parameters.out[-4]
+            }
+            optima.level <- optima.level + 1
+        },
+        Trend = {
+            parameters.out <- model.output.pars[c(1:2, 7)]
+        },
+        EB = {
+            parameters.out <- model.output.pars[c(1:2, 8)]
+        },
+        Stasis = {
+            parameters.out <- model.output.pars[c(5,6)]
+            stasis.level <- stasis.level + 1
+        },
+        multi.OU = {
+            if(length(time.split) == 1) {
+                    parameters.out <- model.output.pars[c(1:4, 9)]
+                    if(fixed.optima) parameters.out <- parameters.out[-4]
+            }
+            if(length(time.split) == 2) {
+                    parameters.out <- model.output.pars[c(1:4, 9:10)]
+                    if(fixed.optima) parameters.out <- parameters.out[-4]
+            }
+            if(length(time.split) == 3) {
+                    parameters.out <- model.output.pars[c(1:4, 9:11)]
+                    if(fixed.optima) parameters.out <- parameters.out[-4]
+            }
         }
-    if(first.model == "OU") {
-        parameters.out <- model.output.pars[c(1:4)]
-        if(fixed.optima) parameters.out <- parameters.out[-4]
-        optima.level <- optima.level + 1
-        }
-    if(first.model == "Trend") {
-        parameters.out <- model.output.pars[c(1:2, 7)]
-        }
-    if(first.model == "EB") {
-        parameters.out <- model.output.pars[c(1:2, 8)]
-        }
-    if(first.model == "Stasis") {
-        parameters.out <- model.output.pars[c(5,6)]
-        stasis.level <- stasis.level + 1
-        }
-    if(first.model == "multi.OU") {
-        if(length(time.split) == 1) {
-                parameters.out <- model.output.pars[c(1:4, 9)]
-                if(fixed.optima) parameters.out <- parameters.out[-4]
-        }
-        if(length(time.split) == 2) {
-                parameters.out <- model.output.pars[c(1:4, 9:10)]
-                if(fixed.optima) parameters.out <- parameters.out[-4]
-        }
-        if(length(time.split) == 3) {
-                parameters.out <- model.output.pars[c(1:4, 9:11)]
-                if(fixed.optima) parameters.out <- parameters.out[-4]
-        }
-    }
+    )
 
     if(n.models > 1) {
         
         for(y in 2:n.models) {
             second.model <- models[y]
         
-            if(second.model == "BM") {
-                parameters.out <- c(parameters.out, model.output.pars[2])
-            }
-
-            if(second.model == "OU") {
-                opt <- c(4, 9:10)[optima.level]
-                parameters.out <- c(parameters.out, model.output.pars[c(2:3, opt)])
-                optima.level <- optima.level + 1
-            }
-            
-            if(second.model == "Trend") {
-                parameters.out <- c(parameters.out, model.output.pars[c(2, 7)])
-            }
-            
-            if(second.model == "EB") {
-                parameters.out <- c(parameters.out, model.output.pars[c(2, 8)])
-            }
-            
-            if(second.model == "Stasis") {
-                stasis.opt <- c(5, 11:12)[stasis.level]
-                parameters.out <- c(parameters.out, model.output.pars[c(6, stasis.opt)])
-                stasis.level <- stasis.level + 1
+            switch(second.model,
+                BM = {
+                    parameters.out <- c(parameters.out, model.output.pars[2])
+                },
+                OU = {
+                    opt <- c(4, 9:10)[optima.level]
+                    parameters.out <- c(parameters.out, model.output.pars[c(2:3, opt)])
+                    optima.level <- optima.level + 1
+                },
+                Trend = {
+                    parameters.out <- c(parameters.out, model.output.pars[c(2, 7)])
+                },
+                EB = {
+                    parameters.out <- c(parameters.out, model.output.pars[c(2, 8)])
+                },
+                Stasis = {
+                    stasis.opt <- c(5, 11:12)[stasis.level]
+                    parameters.out <- c(parameters.out, model.output.pars[c(6, stasis.opt)])
+                    stasis.level <- stasis.level + 1
                 }
+            )
         }
 
         too.many <- duplicated(names(parameters.out))
@@ -136,7 +138,7 @@ get.parameters <- function(model.output.pars, models, time.split, fixed.optima=N
 bm.parameters <- function (data.model.test) {
     
     sample.size <- length(data.model.test$central_tendency) - 1
-    round.median.sample.size <- round(median(sample.size))
+    round.median.sample.size <- round(median(sample.size, na.rm = TRUE))
     t.step <- (data.model.test$subsets[sample.size + 1] - data.model.test$subsets[1]) / sample.size
     epsilon <- 2 * pooled.variance(data.model.test) / round.median.sample.size
        data.model.test.difference <- diff(data.model.test$central_tendency)
@@ -147,8 +149,8 @@ stasis.parameters <- function (data.model.test) {
     
     sample.size <- length(data.model.test$central_tendency)
     var.pooled <- pooled.variance(data.model.test)
-    theta <- mean(data.model.test$central_tendency[2:sample.size])
-    omega <- var(data.model.test$central_tendency[2:sample.size]) - var.pooled / median(data.model.test$sample_size)
+    theta <- mean(data.model.test$central_tendency[2:sample.size], na.rm = TRUE)
+    omega <- var(data.model.test$central_tendency[2:sample.size], na.rm = TRUE) - var.pooled / median(data.model.test$sample_size, na.rm = TRUE)
     return(c(omega, theta))
 }
 
@@ -156,9 +158,9 @@ eb.parameters <- function (data.model.test) {
     
     sample.size <- length(data.model.test$central_tendency) - 1
     t.step <- (data.model.test$subsets[sample.size + 1] - data.model.test$subsets[1]) / sample.size
-    epsilon <- 2 * pooled.variance(data.model.test) / round(median(data.model.test$sample_size))
+    epsilon <- 2 * pooled.variance(data.model.test) / round(median(data.model.test$sample_size, na.rm = TRUE))
     data.model.test.difference <- diff(data.model.test$central_tendency)
-    mean.difference <- mean(data.model.test.difference)
+    mean.difference <- mean(data.model.test.difference, na.rm = TRUE)
     sigma.squared.step <- (1 / t.step) * ((1 / sample.size) * sum(mean.difference ^ 2) - epsilon)
     a <- log(1e-5) / max(data.model.test$subsets) * (1/2)
     return(c(sigma.squared.step, a))
@@ -168,9 +170,9 @@ trend.parameters <- function (data.model.test)  {
     
     sample.size <- length(data.model.test$central_tendency) - 1
     t.step <- (data.model.test$subsets[sample.size + 1] - data.model.test$subsets[1]) / sample.size
-    epsilon <- 2 * pooled.variance(data.model.test) / round(median(data.model.test$sample_size))
+    epsilon <- 2 * pooled.variance(data.model.test) / round(median(data.model.test$sample_size, na.rm = TRUE))
     data.model.test.difference <- diff(data.model.test$central_tendency)
-    mean.difference <- mean(data.model.test.difference)
+    mean.difference <- mean(data.model.test.difference, na.rm = TRUE)
     trend.param <- mean.difference / t.step 
     sigma.squared.step <- (1 / t.step) * ((1 / sample.size) * sum(data.model.test.difference ^ 2) - mean.difference^2 - epsilon)
     return(c(sigma.squared.step, trend.param))
@@ -318,7 +320,7 @@ est.VCV <- function(p, data.model.test, model.type, est.anc=TRUE, model.anc) {
 ###################
 model.test.lik <- function(model.test_input, model.type.in, time.split, control.list, fixed.optima) {
 
-    half.life <- (model.test_input$subsets[length(model.test_input$subsets)] - model.test_input$subsets[1]) / 4    
+    half.life <- (model.test_input$subsets[length(model.test_input$subsets)] - model.test_input$subsets[1]) / 4
     sts.params <- stasis.parameters(model.test_input)
     p <- c()
     p[1] <- model.test_input$central_tendency[1]
@@ -338,20 +340,20 @@ model.test.lik <- function(model.test_input, model.type.in, time.split, control.
     lower.bounds <- c(NA, 1e-8, 1e-8, NA, NA, 1e-8, -100, -100, NA, NA, NA, NA)
     upper.bounds <- c(NA, 100, 100, NA, NA, 20, 100, -1e-8, NA, NA, NA, NA)
     
-    model.output <- stats::optim(par = p, fn = opt.mode,  method = "L", control = control.list, model.type.in = model.type.in, time.split=time.split, data.model.test = model.test_input, lower = lower.bounds, upper = upper.bounds, fixed.optima = fixed.optima)
+    model.output <- stats::optim(par = p, fn = opt.mode,  method = "L", control = control.list, model.type.in = model.type.in, time.split = time.split, data.model.test = model.test_input, lower = lower.bounds, upper = upper.bounds, fixed.optima = fixed.optima)
     
     model.type.in
     
     model.output.pars <- model.output[[1]]
     names(model.output.pars) <- c("ancestral state", "sigma squared", "alpha", "optima.1", "theta.1", "omega", "trend", "eb", "optima.2", "optima.3", "theta.2", "theta.3")
-    model.output$par <- get.parameters(model.output.pars, model.type.in, time.split=time.split, fixed.optima=fixed.optima)
+    model.output$par <- get.parameters(model.output.pars, model.type.in, time.split = time.split, fixed.optima = fixed.optima)
     return(model.output)
 }
 
 opt.mode <- function(p, model.type.in, time.split, data.model.test, fixed.optima)  {
      
      
-    if(!is.null(time.split)) time.split <-  sort(sapply(time.split, function(u) which.min(abs(u - rev(data.model.test[[4]])))))
+    if(!is.null(time.split)) time.split <- sort(sapply(time.split, function(u) which.min(abs(u - rev(data.model.test[[4]])))))
      
     total.n <- length(data.model.test$subsets)
     sample.time <- 1:total.n
@@ -460,7 +462,7 @@ opt.mode <- function(p, model.type.in, time.split, data.model.test, fixed.optima
     total_VCV[split.here.vcv[time.x] : (split.here.2.vcv[time.x]), split.here.vcv[time.x] : (split.here.2.vcv[time.x]) ] <- output.vcv
     total_mean <-  c(total_mean, output.mean)
     }
-    mnormt::dmnorm(t(data.model.test$central_tendency), mean =  total_mean, varcov = total_VCV, log = TRUE)
+    mnormt::dmnorm(t(data.model.test$central_tendency), mean = total_mean, varcov = total_VCV, log = TRUE)
 }
 
 
